Package: generics
Title: Common S3 Generics not Provided by Base R Methods Related to
        Model Fitting
Version: 0.1.4
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-4757-117X")),
    person("Max", "Kuhn", , "max@posit.co", role = "aut"),
    person("Davis", "Vaughan", , "davis@posit.co", role = "aut"),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "https://ror.org/03wc8by49"))
  )
Description: In order to reduce potential package dependencies and
    conflicts, generics provides a number of commonly used S3 generics.
License: MIT + file LICENSE
URL: https://generics.r-lib.org, https://github.com/r-lib/generics
BugReports: https://github.com/r-lib/generics/issues
Depends: R (>= 3.6)
Imports: methods
Suggests: covr, pkgload, testthat (>= 3.0.0), tibble, withr
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-05-09 18:17:41 UTC; hadleywickham
Author: Hadley Wickham [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4757-117X>),
  Max Kuhn [aut],
  Davis Vaughan [aut],
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Hadley Wickham <hadley@posit.co>
Repository: CRAN
Date/Publication: 2025-05-09 23:50:06 UTC
Built: R 4.4.0; ; 2026-07-17 18:14:26 UTC; unix
