% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/a.r
\name{single_method.default}
\alias{single_method.default}
\title{Test default}
\usage{
\method{single_method}{default}(x)
}
\arguments{
\item{x}{A parameter}
}
\description{
Test default
}
