% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/a.r
\name{multi_method}
\alias{multi_method}
\title{Generic test for multiple methods}
\usage{
multi_method(x, y)
}
\arguments{
\item{x, y}{A parameter}
}
\description{
Generic test for multiple methods
}
