% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/a.r
\name{same_rd_name}
\alias{same_rd_name}
\title{Generic test for multiple methods on the same rd file}
\usage{
same_rd_name(x)
}
\arguments{
\item{x}{A parameter}
}
\description{
Should be comma separated
}
