% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/a.r
\name{tidy.special_method}
\alias{tidy.special_method}
\title{Test default}
\usage{
\method{tidy}{special_method}(x, ...)
}
\arguments{
\item{x}{A parameter}
}
\description{
Test default
}
