% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/a.r
\name{single_method}
\alias{single_method}
\title{Generic test}
\usage{
single_method(x)
}
\arguments{
\item{x}{A parameter}
}
\description{
Generic test
}
