% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/a.r
\name{multi_method.matrix}
\alias{multi_method.matrix}
\title{Test data frame}
\usage{
multi_method.matrix(x, y)
}
\arguments{
\item{x, y}{A parameter}
}
\description{
Test data frame
}
