% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/a.r
\name{multi_method.default}
\alias{multi_method.default}
\title{Test default}
\usage{
\method{multi_method}{default}(x, y)
}
\arguments{
\item{x, y}{A parameter}
}
\description{
Test default
}
